# Object-Graph-Mapper for KAPPS

# License

The package is licensed under the [MIT license](LICENSE).

# Acknowledgements
This package is developed as part of the INF subproject of the [CRC 1574: Circular Factory for the Perpetual Product](https://www.sfb1574.kit.edu/english/index.php). This work is therefore supported by the Deutsche Forschungsgemeinschaft (DFG, German Research Foundation) [grant-number: SFB-1574-471687386]
